---
title: {{title}}
subtitle: |
	{{institution}} \
	{{faculty}} Co-op \
	{{term}} {{year}} \ 

	{{employer}} \
	{{location}}
author: |
	{{name}} \
	{{student_id}} \
	{{email}} \ 
date: {{date}}
documentclass: article
toc: true
numbersections: true
geometry: margin=3cm

---


